# Elevator Game

A TUI game, thanks to curses, where you control elevators in a building to move people to where they want to go.
The quicker they get to their destination, the more points you get.

Install with `pip install elevator_game`

Play with `python3 -m elevator_game`

You can also play by ssh'ing into the following address. You will need to accept the fingerprint prompt.

`elevator@elevator.mechstack.dev`

And you can play in browser if you don't mind the flickering:

`http://67.205.139.95:8080/`
